"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactFontawesome = require("@fortawesome/react-fontawesome");

var _freeSolidSvgIcons = require("@fortawesome/free-solid-svg-icons");

var _notificationContext = require("../context/notification-context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint-disable no-func-assign */
function getNotificationData(type, extendTypes) {
  if (extendTypes) {
    var data = extendTypes(type);
    if (data) return data;
  }

  switch (type) {
    case 'error':
      return {
        backgroundColor: '#f8615a',
        src: _freeSolidSvgIcons.faExclamationTriangle
      };

    case 'warning':
      return {
        backgroundColor: '#ffd369',
        src: _freeSolidSvgIcons.faExclamationCircle
      };

    case 'info':
      return {
        backgroundColor: '#f4f9f4',
        src: _freeSolidSvgIcons.faInfoCircle
      };

    default:
      return {
        backgroundColor: '#adce74',
        src: _freeSolidSvgIcons.faCheckCircle
      };
  }
}

function Notification(_ref) {
  var type = _ref.type,
      message = _ref.message,
      isOpen = _ref.isOpen,
      id = _ref.id,
      extendTypes = _ref.extendTypes;

  var _useNotification = (0, _notificationContext.useNotification)(),
      removeNotification = _useNotification.removeNotification;

  var _getNotificationData = getNotificationData(type, extendTypes),
      backgroundColor = _getNotificationData.backgroundColor,
      src = _getNotificationData.src;

  return isOpen && /*#__PURE__*/_react["default"].createElement("div", {
    style: {
      backgroundColor: backgroundColor,
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      width: 'fit-content',
      borderRadius: '3px',
      padding: '10px 15px',
      margin: '5px 0'
    }
  }, /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, {
    icon: src
  }), /*#__PURE__*/_react["default"].createElement("p", {
    style: {
      margin: '0 10px',
      fontSize: '14px'
    }
  }, message), /*#__PURE__*/_react["default"].createElement("button", {
    style: {
      background: 'none',
      border: 'none',
      display: 'flex',
      padding: 0,
      cursor: 'pointer'
    },
    onClick: function onClick() {
      return removeNotification(id);
    }
  }, /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, {
    icon: _freeSolidSvgIcons.faTimes
  })));
}

Notification = _react["default"].memo(Notification);
var _default = Notification;
exports["default"] = _default;
module.exports = exports.default;