"use strict";

exports.__esModule = true;
exports.NotificationProvider = NotificationProvider;
exports.useNotification = useNotification;

var _react = _interopRequireWildcard(require("react"));

var _reactPortal = require("react-portal");

var _uuid = require("uuid");

var _Notification = _interopRequireDefault(require("../components/Notification"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var types = {
  addNotification: 'addNotification',
  removeNotification: 'removeNotification'
};
var NotificationContext = (0, _react.createContext)();

function notificationReducer(state, action) {
  switch (action.type) {
    case types.addNotification:
      {
        var _action$payload = action.payload,
            message = _action$payload.message,
            type = _action$payload.type,
            id = _action$payload.id;
        return _extends({}, state, {
          notifications: [].concat(state.notifications, [{
            id: id,
            isOpen: true,
            message: message,
            type: type
          }])
        });
      }

    case types.removeNotification:
      return _extends({}, state, {
        notifications: state.notifications.filter(function (item) {
          return item.id !== action.payload.id;
        })
      });

    default:
      throw new Error("'" + action.type + "': invalid type received.");
  }
}

function NotificationProvider(_ref) {
  var _state$notifications;

  var children = _ref.children,
      _ref$extendTypes = _ref.extendTypes,
      extendTypes = _ref$extendTypes === void 0 ? null : _ref$extendTypes;

  var _useReducer = (0, _react.useReducer)(notificationReducer, {
    notifications: []
  }),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  function removeNotification(id) {
    dispatch({
      type: types.removeNotification,
      payload: {
        id: id
      }
    });
  }
  /**
   * Adds a new notification
   * @param config Customise Notification.
   * @param config.type ["success", "warning", "info", "error"] Customise Notification.
   */


  function showNotification(_ref2) {
    var _ref2$type = _ref2.type,
        type = _ref2$type === void 0 ? 'error' : _ref2$type,
        _ref2$message = _ref2.message,
        message = _ref2$message === void 0 ? 'Something went wrong' : _ref2$message,
        _ref2$autoHide = _ref2.autoHide,
        autoHide = _ref2$autoHide === void 0 ? true : _ref2$autoHide,
        _ref2$hideAfter = _ref2.hideAfter,
        hideAfter = _ref2$hideAfter === void 0 ? 3000 : _ref2$hideAfter;
    var id = (0, _uuid.v4)();
    dispatch({
      type: types.addNotification,
      payload: {
        type: type,
        message: message,
        id: id
      }
    });

    if (autoHide) {
      setTimeout(function () {
        removeNotification(id);
      }, hideAfter);
    }
  }

  var value = (0, _react.useMemo)(function () {
    return {
      showNotification: showNotification,
      removeNotification: removeNotification
    };
  }, []);
  return /*#__PURE__*/_react["default"].createElement(NotificationContext.Provider, {
    value: value
  }, /*#__PURE__*/_react["default"].createElement(_reactPortal.Portal, null, /*#__PURE__*/_react["default"].createElement("div", {
    style: {
      position: 'fixed',
      top: '10px',
      right: '10px',
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'flex-end'
    }
  }, (_state$notifications = state.notifications) === null || _state$notifications === void 0 ? void 0 : _state$notifications.map(function (_ref3) {
    var id = _ref3.id,
        isOpen = _ref3.isOpen,
        message = _ref3.message,
        type = _ref3.type;
    return /*#__PURE__*/_react["default"].createElement(_Notification["default"], {
      key: id,
      id: id,
      type: type,
      message: message,
      isOpen: isOpen,
      extendTypes: extendTypes
    });
  }))), children);
}

function useNotification() {
  var context = (0, _react.useContext)(NotificationContext);

  if (!context) {
    throw new Error('useNotification must be used within a NotificationProvider');
  }

  return context;
}